import penguins as pg

data_2d = pg.read(".", 2, 1)
data_2d.stage(levels=2e5)
fig, ax = pg.mkplot()

ax.text(x=0.5, y=0.5, s="A peak")

ax.text(x=0.5, y=0.5, s="Middle", transform=ax.transAxes

pg.show()



from .dataset import *
from .pgplot import *
from .plotutils import *
from ._version import __version__


# Easy access to color palettes
DEEP = color_palette('deep')
MUTED = color_palette('muted')
PASTEL = color_palette('pastel')
BRIGHT = color_palette('bright')
DARK = color_palette('dark')
COLORBLIND = color_palette('colorblind')
